==> haskell-puremd5-2.1.3-24-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-puremd5.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pureMD5
version: 2.1.3
id: pureMD5-2.1.3-JGiaZFjxwvx3ZBe3kp9Wvj
key: pureMD5-2.1.3-JGiaZFjxwvx3ZBe3kp9Wvj
license: BSD-3-Clause
maintainer: Thomas DuBuisson
author: Thomas DuBuisson <thomas.dubuisson@gmail.com>
stability: stable
synopsis: A Haskell-only implementation of the MD5 digest (hash) algorithm.
description:
    A Haskell-only implementation of the MD5 digest (hash) algorithm.  This now supports
    the crypto-api class interface.
category: Data, Cryptography
abi: fea5374a3be69740a06a467f966f25ec
exposed: True
exposed-modules:
    Data.Digest.Pure.MD5
import-dirs: /usr/lib/ghc-8.6.5/site-local/pureMD5-2.1.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/pureMD5-2.1.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/pureMD5-2.1.3
hs-libraries: HSpureMD5-2.1.3-JGiaZFjxwvx3ZBe3kp9Wvj
depends:
    base-4.12.0.0 binary-0.8.6.0 bytestring-0.10.8.2
    cereal-0.5.8.1-7AyRb7vLva5K85rZXh3kQh
    crypto-api-0.13.3-ALzE3By8BvHGVvnn2irh7V
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP
haddock-interfaces: /usr/share/doc/haskell-puremd5/html/pureMD5.haddock
haddock-html: /usr/share/doc/haskell-puremd5/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-puremd5-2.1.3-25-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-puremd5.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: pureMD5
version: 2.1.3
id: pureMD5-2.1.3-GZudwmc4wjgHSsWyUhLXBF
key: pureMD5-2.1.3-GZudwmc4wjgHSsWyUhLXBF
license: BSD-3-Clause
maintainer: Thomas DuBuisson
author: Thomas DuBuisson <thomas.dubuisson@gmail.com>
stability: stable
synopsis: A Haskell-only implementation of the MD5 digest (hash) algorithm.
description:
    A Haskell-only implementation of the MD5 digest (hash) algorithm.  This now supports
    the crypto-api class interface.
category: Data, Cryptography
abi: 5d79a2de31cc7a2b9252374d2c13e997
exposed: True
exposed-modules:
    Data.Digest.Pure.MD5
import-dirs: /usr/lib/ghc-8.6.5/site-local/pureMD5-2.1.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/pureMD5-2.1.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/pureMD5-2.1.3
hs-libraries: HSpureMD5-2.1.3-GZudwmc4wjgHSsWyUhLXBF
depends:
    base-4.12.0.0 binary-0.8.6.0 bytestring-0.10.8.2
    cereal-0.5.8.1-7AyRb7vLva5K85rZXh3kQh
    crypto-api-0.13.3-Bqlv92FAlG0F3d21zytrBM
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP
haddock-interfaces: /usr/share/doc/haskell-puremd5/html/pureMD5.haddock
haddock-html: /usr/share/doc/haskell-puremd5/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
